==> kmymoney_5.0.8.orig.tar.xz: kmymoney-5.0.8/kmymoney/plugins/xml/xmlstorage.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "ktambascio@users.sourceforge.net,tbaumgart@kde.org,acejones@users.sourceforge.net,lukasz.wojnilowicz@gmail.com",
                "Name": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[ca]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[de]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[en_GB]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[es]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[fr]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[gl]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[it]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[nl]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[pl]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[pt]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[ru]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[sk]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[sv]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[uk]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[x-test]": "xxKevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowiczxx"
            }
        ],
        "Description": "Adds XML storage support to KMyMoney",
        "Description[ca@valencia]": "Afig la implementació de l'emmagatzematge en XML al KMyMoney",
        "Description[ca]": "Afegeix la implementació de l'emmagatzematge en XML al KMyMoney",
        "Description[en_GB]": "Adds XML storage support to KMyMoney",
        "Description[es]": "Añade almacenamiento XML a KMyMoney",
        "Description[fr]": "Ajoute la prise en charge du stockage « XML » à KMyMoney",
        "Description[gl]": "Engade a posibilidade de almacenamento de XML en KMyMoney",
        "Description[it]": "Aggiunge il supporto per l'archiviazione XML a KMyMoney",
        "Description[ko]": "KMyMoney에 XML 스토리지 지원 추가",
        "Description[nl]": "Voegt ondersteuning toe voor XML-opslag aan KMyMoney",
        "Description[pl]": "Dodaje obsługę pamięci XML do KMyMoney",
        "Description[pt]": "Adiciona o suporte do armazenamento em XML ao KMyMoney",
        "Description[pt_BR]": "Adiciona suporte ao armazenamento XML no KMyMoney",
        "Description[sk]": "Pridáva podporu XML úložiska do KMyMoney",
        "Description[sv]": "Lägger till stöd för XML-lagring i KMyMoney",
        "Description[uk]": "Підтримка сховищ XML у KMyMoney",
        "Description[x-test]": "xxAdds XML storage support to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "server-database",
        "Id": "xmlstorage",
        "License": "GPL",
        "Name": "XML Storage",
        "Name[ca@valencia]": "Emmagatzematge XML",
        "Name[ca]": "Emmagatzematge XML",
        "Name[de]": "XML-Speicher",
        "Name[en_GB]": "XML Storage",
        "Name[es]": "Almacenamiento XML",
        "Name[fr]": "Stockage XML",
        "Name[gl]": "Almacenamento de XML",
        "Name[it]": "Archiviazione XML",
        "Name[nl]": "XML-opslag",
        "Name[pl]": "Pamięć XML",
        "Name[pt]": "Armazenamento em XML",
        "Name[pt_BR]": "Armazenamento XML",
        "Name[sk]": "XML Úložisko",
        "Name[sv]": "XML-lagring",
        "Name[uk]": "Сховище XML",
        "Name[x-test]": "xxXML Storagexx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney-5.1.0.tar.xz: kmymoney-5.1.0/kmymoney/plugins/xml/xmlstorage.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "ktambascio@users.sourceforge.net,tbaumgart@kde.org,acejones@users.sourceforge.net,lukasz.wojnilowicz@gmail.com",
                "Name": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[ca]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[de]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[en_GB]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[es]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[eu]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[fr]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[gl]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[it]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[ko]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[nl]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[pl]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[pt]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[ru]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[sk]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[sv]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[uk]": "Kevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowicz",
                "Name[x-test]": "xxKevin Tambascio,Thomas Baumgart,Ace Jones,Łukasz Wojniłowiczxx"
            }
        ],
        "Description": "Adds XML storage support to KMyMoney",
        "Description[ca@valencia]": "Afig la implementació de l'emmagatzematge en XML al KMyMoney",
        "Description[ca]": "Afegeix la implementació de l'emmagatzematge en XML al KMyMoney",
        "Description[en_GB]": "Adds XML storage support to KMyMoney",
        "Description[es]": "Añade almacenamiento XML a KMyMoney",
        "Description[eu]": "XML biltegiratze euskarria gehitzen dio KMyMoneyri",
        "Description[fr]": "Ajoute la prise en charge du stockage « XML » à KMyMoney",
        "Description[gl]": "Engade a posibilidade de almacenamento de XML en KMyMoney",
        "Description[it]": "Aggiunge il supporto per l'archiviazione XML a KMyMoney",
        "Description[ko]": "KMyMoney에 XML 저장소 지원 추가",
        "Description[nl]": "Voegt ondersteuning toe voor XML-opslag aan KMyMoney",
        "Description[pl]": "Dodaje obsługę pamięci XML do KMyMoney",
        "Description[pt]": "Adiciona o suporte do armazenamento em XML ao KMyMoney",
        "Description[pt_BR]": "Adiciona suporte ao armazenamento XML no KMyMoney",
        "Description[sk]": "Pridáva podporu XML úložiska do KMyMoney",
        "Description[sv]": "Lägger till stöd för XML-lagring i KMyMoney",
        "Description[uk]": "Підтримка сховищ XML у KMyMoney",
        "Description[x-test]": "xxAdds XML storage support to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "server-database",
        "Id": "xmlstorage",
        "License": "GPL",
        "Name": "XML Storage",
        "Name[ca@valencia]": "Emmagatzematge XML",
        "Name[ca]": "Emmagatzematge XML",
        "Name[de]": "XML-Speicher",
        "Name[en_GB]": "XML Storage",
        "Name[es]": "Almacenamiento XML",
        "Name[eu]": "XML biltegiratzea",
        "Name[fr]": "Stockage XML",
        "Name[gl]": "Almacenamento de XML",
        "Name[it]": "Archiviazione XML",
        "Name[ko]": "XML 저장소",
        "Name[nl]": "XML-opslag",
        "Name[pl]": "Pamięć XML",
        "Name[pt]": "Armazenamento em XML",
        "Name[pt_BR]": "Armazenamento XML",
        "Name[sk]": "XML Úložisko",
        "Name[sv]": "XML-lagring",
        "Name[uk]": "Сховище XML",
        "Name[x-test]": "xxXML Storagexx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
